@@ -1,5 +1,5 @@
 package App::Bot::BasicBot::Pluggable;
-$App::Bot::BasicBot::Pluggable::VERSION = '1.00';
+$App::Bot::BasicBot::Pluggable::VERSION = '1.10';
 use Moose;
 use Config::Find;
 use Bot::BasicBot::Pluggable;
@@ -51,6 +51,8 @@ has channel => (
 );
 has password => ( is => 'rw', isa => 'Str' );
 has port => ( is => 'rw', isa => 'Int', default => 6667 );
+has useipv6  => ( is => 'rw', isa => 'Bool', default => 1 );
+has localaddr => ( is => 'rw', isa => 'Str' );
 has bot_class =>
   ( is => 'rw', isa => 'Str', default => 'Bot::BasicBot::Pluggable' );
 
@@ -144,6 +146,8 @@ sub _create_bot {
         nick      => $self->nick(),
         charset   => $self->charset(),
         port      => $self->port(),
+        useipv6   => $self->useipv6(),
+        localaddr => $self->localaddr(),
         store     => $self->store(),
         loglevel  => $self->loglevel(),
         logconfig => $self->logconfig(),
@@ -178,7 +182,7 @@ App::Bot::BasicBot::Pluggable - Base class for bot applications
 
 =head1 VERSION
 
-version 1.00
+version 1.10
 
 =head1 SYNOPSIS
 
