@@ -1,7 +1,5 @@
 package Bot::BasicBot::Pluggable;
-{
-  $Bot::BasicBot::Pluggable::VERSION = '0.97';
-}
+$Bot::BasicBot::Pluggable::VERSION = '1.10';
 use warnings;
 use strict;
 
@@ -179,7 +177,15 @@ sub handler {
 
 sub handlers {
     my $self = shift;
-    my @keys = keys( %{ $self->{handlers} } );
+    my @keys = sort {
+	my $xa = $self->handler($a);
+	my $xb = $self->handler($b);
+	(
+	    ($xb->get('user_priority') || $xb->get('priority') || 0)
+		<=>
+	    ($xa->get('user_priority') || $xa->get('priority') || 0)
+	) || ($a cmp $b)
+    } keys( %{ $self->{handlers} } );
     return @keys if wantarray;
     return \@keys;
 }
@@ -372,7 +378,7 @@ Bot::BasicBot::Pluggable - extended simple IRC bot for pluggable modules
 
 =head1 VERSION
 
-version 0.97
+version 1.10
 
 =head1 SYNOPSIS
 
@@ -460,7 +466,7 @@ The perldoc pages for the various modules will list other commands.
 
 Bot::BasicBot::Pluggable started as Yet Another Infobot replacement, but now
 is a generalised framework for writing infobot-type bots that lets you keep
-each specific function seperate. You can have seperate modules for factoid
+each specific function separate. You can have separate modules for factoid
 tracking, 'seen' status, karma, googling, etc. Included default modules are
 below. Use C<perldoc Bot::BasicBot::Pluggable::Module::<module name>> for help
 on their individual terminology.
@@ -503,7 +509,7 @@ if not.
 
 Reload the module C<$module> - equivalent to unloading it (if it's already
 loaded) and reloading it. Will stomp the old module's namespace - warnings
-are expected here. Not toally clean - if you're experiencing odd bugs, restart
+are expected here. Not totally clean - if you're experiencing odd bugs, restart
 the bot if possible. Works for minor bug fixes, etc.
 
 =item unload($module)
@@ -552,7 +558,7 @@ It expects trace, debug, info, warn, error or fatal as value.
 
 Returns the bot configuration file for logging. Please refer to
 L<Log::Log4perl::Config> for the configurations files format. Setting
-this to a differant file after calling init() has no effect.
+this to a different file after calling init() has no effect.
 
 Returns or set 
 
@@ -593,7 +599,7 @@ and/or modify it under the same terms as Perl itself.
 
 =head1 AUTHOR
 
-Mike Eldridge <diz@cpan.org>
+David Precious (BIGPRESH) <davidp@preshweb.co.uk>
 
 I am merely the current maintainer; however, the AUTHOR heading is traditional.
 
@@ -607,6 +613,8 @@ I am merely the current maintainer; however, the AUTHOR heading is traditional.
 
 =item * David Precious <davidp@preshweb.co.uk>
 
+=item * Mike Eldridge <diz@cpan.org>
+
 =back
 
 =head1 CREDITS
@@ -626,6 +634,9 @@ And thanks to the rest of #2lmc who were my unwilling guinea pigs during
 development. And who kept suggesting totally stupid ideas for modules that I
 then felt compelled to go implement. Shout.pm owes its existence to #2lmc.
 
+Thanks to Mike Eldridge (DIZ), maintainer until 2016, for kindly transferring
+maintainership to me, BIGPRESH, so I can keep this useful bot framework alive.
+
 =head1 SEE ALSO
 
 =over 2
