@@ -1,7 +1,5 @@
 package Bot::BasicBot::Pluggable::Module::Join;
-{
-  $Bot::BasicBot::Pluggable::Module::Join::VERSION = '0.98';
-}
+$Bot::BasicBot::Pluggable::Module::Join::VERSION = '1.10';
 use base qw(Bot::BasicBot::Pluggable::Module);
 use warnings;
 use strict;
@@ -12,7 +10,7 @@ sub connected {
 
     ## If we are not a array reference, we are problably the old
     ## string format ... trying to convert
-    if ( not ref($channels) eq 'ARRAY' ) {
+    if ( not ref($channels) && $channels =~ 'ARRAY' ) {
         $channels = [ split( /\s+/, $channels ) ];
     }
 
@@ -75,14 +73,14 @@ sub told {
 sub chanjoin {
     my ( $self, $mess ) = @_;
     if ( $mess->{who} eq $self->bot->nick ) {
-        $self->set( channels => $self->bot->channels );
+        $self->set( channels => [ $self->bot->channels ] );
     }
 }
 
 sub chanpart {
     my ( $self, $mess ) = @_;
     if ( $mess->{who} eq $self->bot->nick ) {
-        $self->set( channels => $self->bot->channels );
+        $self->set( channels => [ $self->bot->channels ] );
     }
 }
 
@@ -106,7 +104,7 @@ Bot::BasicBot::Pluggable::Module::Join - join and leave channels; remembers stat
 
 =head1 VERSION
 
-version 0.98
+version 1.10
 
 =head1 IRC USAGE
 
