@@ -1,5 +1,5 @@
 package Bot::BasicBot::Pluggable::Module::Karma;
-$Bot::BasicBot::Pluggable::Module::Karma::VERSION = '1.00';
+$Bot::BasicBot::Pluggable::Module::Karma::VERSION = '1.10';
 use base qw(Bot::BasicBot::Pluggable::Module);
 use warnings;
 use strict;
@@ -12,6 +12,7 @@ sub init {
             user_num_comments      => 3,
             user_show_givers       => 1,
             user_randomize_reasons => 1,
+	    user_karma_change_response => 1,
         }
     );
 }
@@ -123,7 +124,7 @@ sub get_karma {
     $thing = lc($thing);
     $thing =~ s/-/ /g;
 
-    my @changes = @{ $self->get("karma_$thing") || [] };
+    my @changes = grep { ref } @{ $self->get("karma_$thing") || [] };
 
     my ( @good, @bad );
     my $karma    = 0;
@@ -134,8 +135,8 @@ sub get_karma {
 
         # just push non empty reasons on the array
         my $reason = $row->{reason};
-        if ( $row->{positive} ) { $positive++; push( @good, $row ) if $reason }
-        else                    { $negative++; push( @bad, $row ) if $reason }
+        if ( $row->{positive} ) { $positive++; push( @good, +{ %$row } ) if $reason }
+        else                    { $negative++; push( @bad, +{ %$row } ) if $reason }
     }
     $karma = $positive - $negative;
 
@@ -159,7 +160,7 @@ sub add_karma {
     $thing =~ s/-/ /g;
     my $row =
       { reason => $reason, who => $who, timestamp => time, positive => $good };
-    my @changes = @{ $self->get("karma_$thing") || [] };
+    my @changes = map { +{ %$_ } } grep { ref } @{ $self->get("karma_$thing") || [] };
     push @changes, $row;
     $self->set( "karma_$thing" => \@changes );
     my $respond = $self->get('user_karma_change_response');
@@ -205,7 +206,7 @@ Bot::BasicBot::Pluggable::Module::Karma - tracks karma for various concepts
 
 =head1 VERSION
 
-version 1.00
+version 1.10
 
 =head1 IRC USAGE
 
