@@ -66,7 +66,7 @@ sub told {
     my ( $command, $param ) = split( /\s+/, $body, 2 );
     $command = lc($command);
 
-    if ( $command eq "seen" and $param =~ /^(.+?)\??$/ ) {
+    if ( $command eq "seen" and $param =~ /^(\S+)\??$/ ) {
         my $who  = lc($1);
         my $seen = $self->get("seen_$who");
     
@@ -154,7 +154,7 @@ Bot::BasicBot::Pluggable::Module::Seen - track when and where people were seen
 
 =head1 VERSION
 
-version 0.98
+version 1.10
 
 =head1 IRC USAGE
 
