@@ -1,7 +1,5 @@
 package Bot::BasicBot::Pluggable::Module::Title;
-{
-  $Bot::BasicBot::Pluggable::Module::Title::VERSION = '0.98';
-}
+$Bot::BasicBot::Pluggable::Module::Title::VERSION = '1.10';
 use base qw(Bot::BasicBot::Pluggable::Module);
 use warnings;
 use strict;
@@ -31,6 +29,10 @@ sub admin {
     # do this in admin so we always get a chance to see titles
     my ( $self, $mess ) = @_;
 
+    # If the message was from the bot (for e.g. another module announcing the
+    # title of an URL we just said, etc), go no further, to avoid loops
+    return if $mess->{who} eq $self->bot->nick;
+
     my $ignore_regexp = $self->get('user_ignore_re');
 
     my $reply = "";
@@ -66,7 +68,7 @@ Bot::BasicBot::Pluggable::Module::Title - speaks the title of URLs mentioned
 
 =head1 VERSION
 
-version 0.98
+version 1.10
 
 =head1 IRC USAGE
 
