@@ -1,7 +1,5 @@
 package Bot::BasicBot::Pluggable::Module::Vars;
-{
-  $Bot::BasicBot::Pluggable::Module::Vars::VERSION = '0.97';
-}
+$Bot::BasicBot::Pluggable::Module::Vars::VERSION = '1.10';
 use base qw(Bot::BasicBot::Pluggable::Module);
 use warnings;
 use strict;
@@ -24,7 +22,7 @@ sub told {
         my $module = $self->{Bot}->module($mod);
         return "No such module '$module'." unless $module;
         $value = defined($value) ? $value : '';    # wipe if no value.
-        $module->set( "user_$var", $value );
+        $module->set( "user_$var", $value ) if $var;
         return "Set.";
 
     }
@@ -61,7 +59,7 @@ Bot::BasicBot::Pluggable::Module::Vars - change internal module variables
 
 =head1 VERSION
 
-version 0.97
+version 1.10
 
 =head1 SYNOPSIS
 
